==> geolocator-1.7.0.tar.gz: android/src/main/java/com/baseflow/flutter/plugin/geolocator/tasks/LocationUpdatesUsingLocationManagerTask.java <==
package com.baseflow.flutter.plugin.geolocator.tasks;

import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.location.LocationProvider;
import android.os.Bundle;
import android.os.Looper;

import com.baseflow.flutter.plugin.geolocator.data.GeolocationAccuracy;
import com.baseflow.flutter.plugin.geolocator.data.LocationMapper;
import com.google.android.gms.common.util.Strings;

import java.util.List;
import java.util.Map;

class LocationUpdatesUsingLocationManagerTask extends LocationUsingLocationManagerTask implements LocationListener {
    private final boolean mStopAfterFirstLocationUpdate;
    private Location mBestLocation;
    private String mActiveProvider;

    LocationUpdatesUsingLocationManagerTask(TaskContext context, boolean stopAfterFirstLocationUpdate) {
        super(context);

        mStopAfterFirstLocationUpdate = stopAfterFirstLocationUpdate;
    }

    @Override
    public void startTask() {

        LocationManager locationManager = getLocationManager();

        // Make sure we remove existing listeners before we register a new one
        locationManager.removeUpdates(this);

        // Try to get the best possible location provider for the requested accuracy
        mActiveProvider = getBestProvider(
                locationManager,
                mLocationOptions.accuracy);

        if(Strings.isEmptyOrWhitespace(mActiveProvider)) {
            handleError();

            return;
        }

        mBestLocation = locationManager.getLastKnownLocation(mActiveProvider);

        // If we are listening to multiple location updates we can go ahead
        // and report back the last known location (if we have one).
        if(!mStopAfterFirstLocationUpdate && mBestLocation != null) {
            reportLocationUpdate(mBestLocation);
        }

        Looper looper = Looper.myLooper();
        if(looper == null) {
            looper = Looper.getMainLooper();
        }

        locationManager.requestLocationUpdates(
                mActiveProvider,
                0,
                mLocationOptions.distanceFilter,
                this,
                looper);
    }

    @Override
    public void stopTask() {
        super.stopTask();

        LocationManager locationManager = getLocationManager();
        locationManager.removeUpdates(this);
    }

    private void handleError() {
        getTaskContext().getResult().error(
                "INVALID_LOCATION_SETTINGS",
                "Location settings are inadequate, check your location settings.",
                null);
    }

    private String getBestProvider(LocationManager locationManager, GeolocationAccuracy accuracy) {
        Criteria criteria = new Criteria();

        criteria.setBearingRequired(false);
        criteria.setAltitudeRequired(false);
        criteria.setSpeedRequired(false);

        switch(accuracy) {
            case LOWEST:
                criteria.setAccuracy(Criteria.NO_REQUIREMENT);
                criteria.setHorizontalAccuracy(Criteria.NO_REQUIREMENT);
                criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);
                break;
            case LOW:
                criteria.setAccuracy(Criteria.ACCURACY_COARSE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_LOW);
                criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);
                break;
            case MEDIUM:
                criteria.setAccuracy(Criteria.ACCURACY_COARSE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_MEDIUM);
                criteria.setPowerRequirement(Criteria.POWER_MEDIUM);
                break;
            case HIGH:
                criteria.setAccuracy(Criteria.ACCURACY_FINE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_HIGH);
                criteria.setPowerRequirement(Criteria.POWER_HIGH);
                break;
            case BEST:
                criteria.setAccuracy(Criteria.ACCURACY_FINE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_HIGH);
                criteria.setPowerRequirement(Criteria.POWER_HIGH);
                break;
        }

        String provider = locationManager.getBestProvider(criteria, true);

        if(Strings.isEmptyOrWhitespace(provider)) {
            List<String> providers = locationManager.getProviders(true);
            if(providers != null && providers.size() > 0)
                provider = providers.get(0);
        }

        return provider;
    }

    @Override
    public synchronized void onLocationChanged(Location location) {
        float desiredAccuracy = accuracyToFloat(mLocationOptions.accuracy);
        if(LocationUsingLocationManagerTask.isBetterLocation(location, mBestLocation) && location.getAccuracy() <= desiredAccuracy) {
            mBestLocation = location;
            reportLocationUpdate(location);

            if(mStopAfterFirstLocationUpdate) {
                this.stopTask();
            }
        }
    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle bundle) {
        if (status == LocationProvider.AVAILABLE) {
            onProviderEnabled(provider);
        } else if (status == LocationProvider.OUT_OF_SERVICE) {
            onProviderDisabled(provider);
        }

    }

    @Override
    public void onProviderEnabled(String provider) {

    }

    @Override
    public void onProviderDisabled(String provider) {
        if(provider.equals(mActiveProvider)) {
            getTaskContext().getResult().error(
                    "ERROR_UPDATING_LOCATION",
                    "The active location provider was disabled. Check if the location services are enabled in the device settings.",
                    null);
        }
    }

    private float accuracyToFloat(GeolocationAccuracy accuracy) {
        switch(accuracy) {
            case LOWEST: case LOW: return 500;
            case MEDIUM: return 250;
            case HIGH: return 100;
            case BEST: return 50;
            default: return 100;
        }
    }

    private void reportLocationUpdate(Location location) {
        Map<String, Object> locationMap = LocationMapper.toHashMap(location);

        getTaskContext().getResult().success(locationMap);
    }
}

==> geolocator-2.0.0.tar.gz: android/src/main/java/com/baseflow/flutter/plugin/geolocator/tasks/LocationUpdatesUsingLocationManagerTask.java <==
package com.baseflow.flutter.plugin.geolocator.tasks;

import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.location.LocationProvider;
import android.os.Bundle;
import android.os.Looper;

import com.baseflow.flutter.plugin.geolocator.data.GeolocationAccuracy;
import com.baseflow.flutter.plugin.geolocator.data.PositionMapper;
import com.google.android.gms.common.util.Strings;

import java.util.List;
import java.util.Map;

class LocationUpdatesUsingLocationManagerTask extends LocationUsingLocationManagerTask implements LocationListener {
    private final boolean mStopAfterFirstLocationUpdate;
    private Location mBestLocation;
    private String mActiveProvider;

    LocationUpdatesUsingLocationManagerTask(TaskContext context, boolean stopAfterFirstLocationUpdate) {
        super(context);

        mStopAfterFirstLocationUpdate = stopAfterFirstLocationUpdate;
    }

    @Override
    public void startTask() {

        LocationManager locationManager = getLocationManager();

        // Make sure we remove existing listeners before we register a new one
        locationManager.removeUpdates(this);

        // Try to get the best possible location provider for the requested accuracy
        mActiveProvider = getBestProvider(
                locationManager,
                mLocationOptions.accuracy);

        if(Strings.isEmptyOrWhitespace(mActiveProvider)) {
            handleError();

            return;
        }

        mBestLocation = locationManager.getLastKnownLocation(mActiveProvider);

        // If we are listening to multiple location updates we can go ahead
        // and report back the last known location (if we have one).
        if(!mStopAfterFirstLocationUpdate && mBestLocation != null) {
            reportLocationUpdate(mBestLocation);
        }

        Looper looper = Looper.myLooper();
        if(looper == null) {
            looper = Looper.getMainLooper();
        }

        locationManager.requestLocationUpdates(
                mActiveProvider,
                mLocationOptions.timeInterval,
                mLocationOptions.distanceFilter,
                this,
                looper);
    }

    @Override
    public void stopTask() {
        super.stopTask();

        LocationManager locationManager = getLocationManager();
        locationManager.removeUpdates(this);
    }

    private void handleError() {
        getTaskContext().getResult().error(
                "INVALID_LOCATION_SETTINGS",
                "Location settings are inadequate, check your location settings.",
                null);
    }

    private String getBestProvider(LocationManager locationManager, GeolocationAccuracy accuracy) {
        Criteria criteria = new Criteria();

        criteria.setBearingRequired(false);
        criteria.setAltitudeRequired(false);
        criteria.setSpeedRequired(false);

        switch(accuracy) {
            case LOWEST:
                criteria.setAccuracy(Criteria.NO_REQUIREMENT);
                criteria.setHorizontalAccuracy(Criteria.NO_REQUIREMENT);
                criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);
                break;
            case LOW:
                criteria.setAccuracy(Criteria.ACCURACY_COARSE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_LOW);
                criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);
                break;
            case MEDIUM:
                criteria.setAccuracy(Criteria.ACCURACY_COARSE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_MEDIUM);
                criteria.setPowerRequirement(Criteria.POWER_MEDIUM);
                break;
            case HIGH:
                criteria.setAccuracy(Criteria.ACCURACY_FINE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_HIGH);
                criteria.setPowerRequirement(Criteria.POWER_HIGH);
                break;
            case BEST:
                criteria.setAccuracy(Criteria.ACCURACY_FINE);
                criteria.setHorizontalAccuracy(Criteria.ACCURACY_HIGH);
                criteria.setPowerRequirement(Criteria.POWER_HIGH);
                break;
        }

        String provider = locationManager.getBestProvider(criteria, true);

        if(Strings.isEmptyOrWhitespace(provider)) {
            List<String> providers = locationManager.getProviders(true);
            if(providers != null && providers.size() > 0)
                provider = providers.get(0);
        }

        return provider;
    }

    @Override
    public synchronized void onLocationChanged(Location location) {
        float desiredAccuracy = accuracyToFloat(mLocationOptions.accuracy);
        if(LocationUsingLocationManagerTask.isBetterLocation(location, mBestLocation) && location.getAccuracy() <= desiredAccuracy) {
            mBestLocation = location;
            reportLocationUpdate(location);

            if(mStopAfterFirstLocationUpdate) {
                this.stopTask();
            }
        }
    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle bundle) {
        if (status == LocationProvider.AVAILABLE) {
            onProviderEnabled(provider);
        } else if (status == LocationProvider.OUT_OF_SERVICE) {
            onProviderDisabled(provider);
        }

    }

    @Override
    public void onProviderEnabled(String provider) {

    }

    @Override
    public void onProviderDisabled(String provider) {
        if(provider.equals(mActiveProvider)) {
            getTaskContext().getResult().error(
                    "ERROR_UPDATING_LOCATION",
                    "The active location provider was disabled. Check if the location services are enabled in the device settings.",
                    null);
        }
    }

    private float accuracyToFloat(GeolocationAccuracy accuracy) {
        switch(accuracy) {
            case LOWEST: case LOW: return 500;
            case MEDIUM: return 250;
            case HIGH: return 100;
            case BEST: return 50;
            default: return 100;
        }
    }

    private void reportLocationUpdate(Location location) {
        Map<String, Object> locationMap = PositionMapper.toHashMap(location);

        getTaskContext().getResult().success(locationMap);
    }
}
